@@ -1,10 +1,10 @@
 from __future__ import absolute_import, unicode_literals
-
+from datetime import datetime
 from django.core import management
 from celery import Celery
-from celery.utils.log import get_task_logger
+import os
 
-logger = get_task_logger(__name__)
+os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
 app = Celery('webspace.bakery')
 app.config_from_object('webspace.bakery.celeryconfig', namespace='CELERY')
 app.autodiscover_tasks()
@@ -12,6 +12,11 @@ app.autodiscover_tasks()
 
 @app.task(bind=True)
 def bakery_build(self):
-    logger.info(app.AsyncResult(self.request.id).state)
+    from .models import TaskBuild
+    task_obj = TaskBuild.objects.create()
+    task_obj.task_id = self.request.id
+    task_obj.save()
     management.call_command('build')
-    print("bakery build")
+    task_obj.date_end = datetime.now()
+    task_obj.ready = True
+    task_obj.save()
