@@ -17,9 +17,17 @@ def get_package_version(file_path):
 def run_sentry():
     import sentry_sdk
     from sentry_sdk.integrations.django import DjangoIntegration
+    from sentry_sdk.integrations.logging import LoggingIntegration
+    import logging
     sentry_sdk.init(
         dsn="https://677252655469434897723bab86b18ef0@o419846.ingest.sentry.io/5336964",
-        integrations=[DjangoIntegration()],
+        integrations=[
+            DjangoIntegration(),
+            LoggingIntegration(
+                level=logging.INFO,
+                event_level=logging.ERROR
+            )
+        ],
         send_default_pii=True
     )
 
@@ -230,6 +238,11 @@ LOGGING = {
             'level': 'DEBUG',
             'propagate': True,
             'handlers': ['console'],
-        }
+        },
+        'minify_schema': {
+            'level': 'DEBUG',
+            'propagate': True,
+            'handlers': ['console'],
+        },
     }
-}
\ No newline at end of file
+}
